@@ -76,8 +76,10 @@ def get_real_filename(path: str) -> str:
     if not Path(path).exists():
         while path.startswith("_"):
             path = path[1:]
+
         path = str(
-            pathlib.Path(__file__).parent.parent.absolute().joinpath("assets").joinpath(path))
+            pathlib.Path(__file__).parent.absolute().joinpath("assets").joinpath(
+                "musics").joinpath(path))
 
     return path
 
